/*
 * Nozzle R Package - CSS Styles
 *
 * Copyright 2012, Broad Institute / Havard Medical School
 * Authored and maintained by Nils Gehlenborg (nils@hms.harvard.edu)
 */


p {
	margin: 0;
	margin-bottom: 5px;
	font-family: Georgia, "Times New Roman", Times, serif;	
}

body {
	margin-top: 20px;
	padding-bottom: 20px;
	margin-left: 0;
	margin-right: 0;
	padding-left: 0;
	padding-right: 0;
}

.report {
	margin-left: 0;
	margin-right: 0;
	padding-left: 0;
	padding-right: 0;	
}

.report .frame {
	margin-left: 0;
	margin-right: 0;
	padding-left: 0;
	padding-right: 0;
}

.report .main {
	padding-left: 0.5in;
	width: 8.5in;
}


.report .title {
	margin-top: 5px;
	margin-bottom: 5px;
	font: bold xx-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	color: #000;
}

.report .maintainer {
	margin-top: 0px;
	margin-bottom: 5px;
	font: small Georgia, "Times New Roman", Times, serif;
	color: #666;
	font-style: italic;
}

.report .maintainer a {
	color: #333;
}

.report .maintainer .name {
	font-style: normal;
	color: #333;
}

.report .copyright {
	margin-top: 30px;
	margin-bottom: 5px;
	text-align: center;
}

.report .copyright .notice {
	font: small Georgia, "Times New Roman", Times, serif;
	color: #666;
	font-style: italic;
}

.report .copyright .notice .owner a {
	color: #333;
}

.report .copyright .notice .owner {
	color: #333;
	font-style: normal;
}

.report .credits {
	margin-top: 35px;
	text-align: center;
	font: bold x-small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.report .credits .notice a {
	color: #fff;
	font-style: normal;
	text-transform: uppercase;
	text-decoration: none;
	background-color: black;
	padding: 0.5ex 3ex 0.5ex 3ex;
	border-radius: 20ex;
}



.report strong {
	font-weight: bold;
}

.report em {
	font-style: italic;
}

.report .parameter {
	display: inline-block;
	font-family: "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	font-style: italic;
}

.report .value {
	display: inline-block;
	font-style: italic;
}

.report .filename {
	display: inline-block;
	font: smaller "Courier New", Courier, mono;
}

.report .code {
	display: inline-block;
	font: smaller "Courier New", Courier, mono;
}

.report .arguments {
	display: compact;
}


.section {
	margin-bottom: 5px;
	margin-top: 5px;
	padding: 0;
}

.subsection {
	margin-bottom: 5px;
	padding: 0;
}


.sectionheader {
	font-family: "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	padding-bottom: 3px;
	font-weight: bold;
	text-indent: -25px;
	padding-left: 25px;
}

.sectionbody {
	font: medium Georgia, "Times New Roman", Times, serif;
}

.section .sectionbody {
	margin-bottom: 0px;
	margin-top: 0px;
	margin-left: 0px;
	padding-bottom: 5px;
	font: medium Georgia, "Times New Roman", Times, serif;
}

.subsection .sectionbody {
	padding-bottom: 5px;
	margin-bottom: 10px;
	margin-top: 0px;
	margin-left: 0px;
	font: medium Georgia, "Times New Roman", Times, serif;
}

.subsubsection .sectionbody {
	padding-bottom: 5px;
	font: medium Georgia, "Times New Roman", Times, serif;
	margin-left: 0px;
}


.sectionbody a {
	color: #777777;
}


.section .sectionheader {
	margin-top: 15px;
	margin-bottom: 12px;
	font: bold x-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #426566;	
	border-bottom: 1pt solid black;		
}

.subsection .sectionheader {
	margin-top: 0px;
	margin-bottom: 8px;
	border-bottom: 0px solid black;	
	font: bold large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #749899;
	border-bottom: 1pt solid #999;		
}

.subsubsection .sectionheader {
	margin-top: 5px;
	margin-bottom: 3px;
	margin-left: 0px;	
	border-bottom: 0px solid black;	
	font: bold medium "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #91bfc0;
}

.meta {
	border-top: 1px dotted #d0d0d0;
	border-bottom: 1px dotted #d0d0d0;
}

.section.meta {
	margin-top: 30px;
	padding-bottom: 8px;
	border-top: 1px dotted #d0d0d0;
	border-bottom: 1px dotted #d0d0d0;
	margin-bottom: 30px;
}

.meta .sectionheader {
	color: #999;
	font-size: 90%;
	border-bottom: 0px;
}

.meta .sectionbody {
	color: #999;
	font-size: 90%;
}

.significant {
}


div.significant {
	background-color: white;
}


span.summary {
	color: #919191;
	cursor: default;
	width: 11px;
	height: 11px;
	display: inline-block;
	position: relative;
	border-radius: 15ex;
	top: -1px;
}


/* @group reference */

.reference {
	text-indent: -25px;
	padding-left: 25px;
	padding-bottom: 5px;
}



/* @end */

/* @group results and evidence */

span.result {
	color: #0773ba;
	padding-right: 0.5ex;
	padding-left: 0.5ex;
	border-radius: 0.8ex;	
	cursor: pointer;
	font-weight: bold;
}

span.result.noevidence {
	text-decoration: none;
	cursor: default;
}

span.result.significant {
	color: #db4105;
}


.resultnumber {
	color: #000000;
	display: block;
	padding: 3px;
	padding-left: 5px;
	/*border-radius: 0.5ex;	*/
	border: 1pt solid #000000;
	font: small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	font-weight: bold;	
}

.resultnumbersup {
	color: #000000;
	border: 1pt solid #000000;
	padding: 2px;
	text-decoration: none;
	/*border-radius: 0.5ex;	*/
	border: 1pt solid #000000;
	font: small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	font-weight: bold;
}

.evidence {
	margin-bottom: 25px;
}

.evidence .sectionheader {
	color: #0773ba;
	margin-left: 0px;
}

.evidence .section .sectionheader {
	padding-bottom: 5px;
	font: bold x-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .subsection .sectionheader {
	padding-bottom: 5px;
	font: bold large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .subsubsection .sectionheader {
	padding-bottom: 5px;
	font: bold medium "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .sectionbody {
	margin: 0;	
}

.evidence .caption {	
	border-color: #0773ba;
}


/* @end */

/* @group resulttable */

.resulttable {
	font-size: small;
	border-style: none;
	border-width: 0px;
	border-collapse: collapse;
	margin-right: auto;
	margin-left: auto;
	font: small Georgia, "Times New Roman", Times, serif;	
}

.resulttable td {
	font-size: small;
	padding-right: 1ex;
	padding-left: 1ex;
	padding-top: 0.75ex;
	padding-bottom: 0.75ex;
}


.resulttable tr {
}

.resulttable thead {
	font-weight: bold;	
	border-bottom: 1px solid #919191;
	border-collapse: separate;
	vertical-align: top;	
}

.resulttable thead th {
	padding-left: 5px;
	padding-right: 5px;		
}

.resulttable.sortabletable thead th {
	cursor: pointer;
}

.resulttable.sortabletable thead th.headerSortUp { 
	color: #426566;
} 

.resulttable.sortabletable thead th.headerSortDown { 
	color: #426566;
} 


.resulttable tbody {
}

.resulttable tbody tr:nth-child(even) {
	background-color: #e4e4e4;
}

.resulttable thead tr {
}



/* @end */

/* @group table and figure */

.table {
	margin-top: 10px;
	margin-bottom: 35px;
	padding: 0px;
	background-color: #ffffff;	
}


.figure {
	margin-top: 10px;
	margin-bottom: 35px;
	padding: 0px;
	background-color: #ffffff;
}

.evidence .figure {
	border-color:  #60a8c8;
}

.figure .image img {
	display: block;
	background-color: #ffffff;
	cursor: pointer;
	margin-right: auto;
	margin-left: auto;
}

/* for SVG */
.figure .image object {
	display: block;
	background-color: #ffffff;
	cursor: pointer;
	margin-right: auto;
	margin-left: auto;
}



.caption {
	margin-top: 0px;
	margin-bottom: 10px;
	font: small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	padding-top: 6px;
	border-bottom: 1px dotted #999;	
}


.caption a.download:hover  {
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;	
}

.caption a.download:active  {
	-webkit-box-shadow: 0px 0px 20px #000000;
	-moz-box-shadow: 0px 0px 20px #000000;
	-opera-box-shadow: 0px 0px 20px #000000;
	box-shadow: 0px 0px 20px #000000;	
}





/* @end */

