/*
 * Nozzle R Package - CSS Styles
 *
 * Copyright 2011-2012, Havard Medical School / Broad Institute
 * Authored and maintained by Nils Gehlenborg (nils@hms.harvard.edu)
 */


#mask
 {
   position: fixed;
   left: 0px; 
   right: 0px; 
   top: 0px; 
   bottom: 0px; 
   background-color: #eeeeee;
   z-index: 99;
}

p {
	margin: 0;
	margin-bottom: 15px;
	font-family: Georgia, "Times New Roman", Times, serif;	
}

li p {
	margin-bottom: 3px;
}


/* @group menu */

.menubar {
	position: relative;
	z-index: 100;
	font: bold x-small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: uppercase;	
}


.menuitem {
	display: inline-block;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 2px;
	padding-bottom: 2px;
	margin-right: 10px;
	border: 1px solid #ccc;
	color: #666666;	
	cursor: pointer;
	border-radius: 0.55ex;
	background-color: #eeeeee;
}

.menuitem a {
	text-decoration: none;
	color: #666666;
}

.menuitem a:visited {
	color: #666666;
}

.menuitem.separator {
	background-color: transparent;
	display: inline-block;
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 2px;
	padding-bottom: 2px;
	margin-right: 10px;
	margin-left: 10px;
	border: 0px;
	color: #666666;	
	cursor: pointer;
}

.menuitem.deactivated {
	cursor: default;
	color: #cccccc;	
}

.menuitem.highlighted {
	color: #eee;	
	background-color: #666;
	border-color: #666;
	margin-right: 0px;
	float: right;
}

.menuitem:hover {
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;	
}

.menuitem.deactivated:hover {
	-webkit-box-shadow: 0px 0px 0px black;
	-moz-box-shadow: 0px 0px 0px black;
	-opera-box-shadow: 0px 0px 0px black;
	box-shadow: 0px 0px 0px black;		
}

.menuitem.separator:hover {
	-webkit-box-shadow: 0px 0px 0px black;
	-moz-box-shadow: 0px 0px 0px black;
	-opera-box-shadow: 0px 0px 0px black;
	box-shadow: 0px 0px 0px black;		
}



.menu {
	padding-top: 7px;	
	top: 0;
	left: 0;
	right: 0;
	position: absolute;
}


/* @end */

/* @group bar */

.bar {
	text-transform: none;
}



/* @end */

/* @group button */

.button {
	font: bold small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: uppercase;
	padding-right: 3px;	
	position: relative;
	top: -0.5ex;
	padding-left: 3px;
	cursor: pointer;
	/*color: #777777;
	background-color: #e4e4e4;*/
	border: 1px #ddd solid;	
	color: #666;
	border-radius: 0.55ex;
}

.button:hover  {
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;	
}

.button:active  {
	-webkit-box-shadow: 0px 0px 20px #000000;
	-moz-box-shadow: 0px 0px 20px #000000;
	-opera-box-shadow: 0px 0px 20px #000000;
	box-shadow: 0px 0px 20px #000000;	
}

.button.contenttoggle {
	font: bold small "Courier New", Courier, mono;
	margin-right: 5px;
}

.button.evidencetoggle {
	font: bold small "Courier New", Courier, mono;

	display: block;
	z-index: 11;
	border-radius: 0.55ex;
	
	background-color: #eee;	
	color: #666666;	
	border: 1px solid #ccc;
	
	position: absolute;
}

.button.evidencetoggle a {
	color: #666666;	
}


.meta .button {
	margin-right: 5px;
	top: -0.3ex;
}



/* @end */

.report {
	background-color: #eeeeee;
	margin: 0px;
	padding: 0px;
	height: 100%;
	position: relative;
}

/* height from http://www.dave-woods.co.uk/?p=144*/
body {
	margin: 0px;	
	padding: 0px;	
}


.report .frame {
	margin: 0px;
	padding: 0px;
	position: relative;
}

.report .main {
	/*width: 100%;*/
	/*max-width: 1000px;*/
	/*min-height: 90%;*/
	/*height: 400px;*/
	font-family: sans-serif;
	margin-right: auto;
	margin-left: auto;
	padding-top: 10px;
	padding-bottom: 20px;		
	padding-left: 30px;
	padding-right: 30px;		
	background-color: #ffffff;
	
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;
	
	/*left: 50%;
	margin-left: -500px;*/
	overflow: auto;
	position: absolute;
	bottom: 0px;
	top: 20px;
	right: 0px;
	left: 0px;
	
	border-top: 5px solid #91bfc0; /*#666666;*/
}

.report .main .logo {
}

.report .main .logo .top {
	margin-top: 10px;
	margin-bottom: 10px;
}

.report .main .logo .bottom {
	margin-top: 20px;
	margin-bottom: 0px;
}

.report .main .logo .left {
	//background-color: yellow;
	width: 33%;
	display: inline-block;
	text-align: left;
	margin: 0px;
}

.report .main .logo .center {
	//background-color: yellowgreen;
	width: 33%;
	display: inline-block;	
	text-align: center;
	margin: 0px;
}

.report .main .logo .right {
	width: 33%;
	display: inline-block;	
	text-align: right;
	margin: 0px;
}


.report .title {
	margin-top: 5px;
	margin-bottom: 0px;
	font: bold xx-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	color: #000;
}

.report .subtitle {
	margin-top: 0px;
	margin-bottom: 5px;
	font: bold large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	color: #666;
}


.report .citation {
	margin-top: 10px;
	margin-bottom: 15px;
	font: small Georgia, "Times New Roman", Times, serif;
	color: #666;
	display: inline;
}

.report .citation a {
	color: #333;
}


.report .freeform {
	/* for freeform HTML elements */
}

.report .maintainer {
	margin-top: 15px;
	margin-bottom: 5px;
	font: small Georgia, "Times New Roman", Times, serif;
	color: #666;
	font-style: normal;
}

.report .maintainer a {
	color: #333;
}

.report .maintainer .name {
	font-style: normal;
	color: #333;
}

.report .copyright {
	margin-top: 30px;
	margin-bottom: 5px;
	text-align: center;
}

.report .copyright .notice {
	font: small Georgia, "Times New Roman", Times, serif;
	color: #666;
	font-style: italic;
}

.report .copyright .notice .owner a {
	color: #333;
}

.report .copyright .notice .owner {
	color: #333;
	font-style: normal;
}


.report .credits {
	margin-top: 35px;
	text-align: center;
	font: bold x-small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.report .credits .notice a {
	color: #fff;
	font-style: normal;
	text-transform: uppercase;
	text-decoration: none;
	background-color: rgba(228,228,228,0.82);
	padding: 0.5ex 3ex 0.5ex 3ex;
	border-radius: 20ex;
}

.report .credits .notice a:hover {
	background-color: black;
}

.report strong {
	font-weight: bold;
}

.report em {
	font-style: italic;
}

.report .parameter {
	display: inline-block;
	font-family: "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	font-style: italic;
	text-decoration: inherit;
}

.report .value {
	display: inline-block;
	font-style: italic;
	text-decoration: inherit;	
}

.report .filename {
	display: inline-block;
	font: smaller "Courier New", Courier, mono;
}

.report .code {
	display: inline-block;
	font: smaller "Courier New", Courier, mono;
}

.report .arguments {
	display: compact;
}


.section {
	margin-bottom: 5px;
	margin-top: 5px;
	padding: 0;
}

.subsection {
	margin-bottom: 5px;
	padding: 0;
}


.sectionheader {
	font-family: "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	padding-bottom: 3px;
	font-weight: bold;
	text-indent: -25px;
	padding-left: 25px;
}

.sectionbody {
	font: medium Georgia, "Times New Roman", Times, serif;
}

.section .sectionbody {
	margin-bottom: 0px;
	margin-top: 0px;
	margin-left: 28px;
	padding-bottom: 5px;
}

.subsection .sectionbody {
	padding-bottom: 5px;
	margin-bottom: 10px;
	margin-top: 0px;
	margin-left: 0px;
}

.subsubsection .sectionbody {
	padding-bottom: 5px;
	margin-left: 0px;
}


.sectionbody a {
	color: #777777;
}

.sectionbody a:hover {
	color: #444444;
}


.section .sectionheader {
	margin-top: 15px;
	margin-bottom: 5px;
	font: bold x-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #426566;	
}

.subsection .sectionheader {
	margin-top: 0px;
	margin-bottom: 3px;
	margin-left: -28px;
	border-bottom: 0px solid black;	
	font: bold large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #749899;
}

.subsubsection .sectionheader {
	margin-top: 5px;
	margin-bottom: 3px;
	margin-left: 0px;	
	border-bottom: 0px solid black;	
	font: bold medium "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: none;
	color: #91bfc0;
}

/* @group Meta */

.meta {
	border-top: 1px dotted #d0d0d0;
	border-bottom: 1px dotted #d0d0d0;
}

.section.meta {
	margin-top: 30px;
	padding-bottom: 8px;
	border-top: 1px dotted #d0d0d0;
	border-bottom: 1px dotted #d0d0d0;
	margin-bottom: 30px;
}

.meta .sectionheader {
	color: #999;
	font-size: 90%;
}

.meta .sectionbody {
	color: #999;
	font-size: 90%;
}

.meta .button {
	border: 0px;
	color: #999;	
}

.meta .button:hover  {
	-webkit-box-shadow: 0px 0px 0px red;
	-moz-box-shadow: 0px 0px 0px red;
	-opera-box-shadow: 0px 0px 0px red;
	box-shadow: 0px 0px 0px red;	
}

.meta .button:active  {
	-webkit-box-shadow: 0px 0px 0px #000000;
	-moz-box-shadow: 0px 0px 0px #000000;
	-opera-box-shadow: 0px 0px 0px #000000;
	box-shadow: 0px 0px 0px #000000;	
}


/* @end */


.significant {
	/*background-color: #ffdacc;*/
}


div.significant {
	/*background-color: white;*/
}


span.summary {
	color: #919191;
	cursor: default;
	width: 11px;
	height: 11px;
	display: inline-block;
	position: relative;
	border-radius: 15ex;
	top: -1px;
}

span.significant {
	background-color: #db4105;
}

span.significant.deactivated {
	background-color: #ffdbcd;
}

span.significant.deactivated:hover {
	-webkit-box-shadow: 0px 0px 5px #db4105;
	-moz-box-shadow: 0px 0px 5px #db4105;
	-opera-box-shadow: 0px 0px 5px #db4105;
	box-shadow: 0px 0px 5px #db4105;
}

span.significant:hover {
	-webkit-box-shadow: 0px 0px 5px #db4105;
	-moz-box-shadow: 0px 0px 5px #db4105;
	-opera-box-shadow: 0px 0px 5px #db4105;
	box-shadow: 0px 0px 5px #db4105;
}


/* @group Reference */

.reference {
	text-indent: -25px;
	padding-left: 25px;
	padding-bottom: 5px;
}



/* @end */

/* @group Supplementary Results */

span.result {
	background-color: #e0eff6;
	color: #0773ba;
	padding-right: 1ex;
	padding-left: 1ex;
	padding-top: 0.1ex;
	padding-bottom: 0.1ex;
	//border-radius: 0.55ex;
	border-radius: 15ex;
	cursor: pointer;
	text-decoration: underline;
}

span.result.noevidence {
	text-decoration: none;
	cursor: default;
}

span.result:hover  {
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;	
}

span.result:active  {
	-webkit-box-shadow: 0px 0px 20px #000000;
	-moz-box-shadow: 0px 0px 20px #000000;
	-opera-box-shadow: 0px 0px 20px #000000;
	box-shadow: 0px 0px 20px #000000;	
}

span.result.noevidence:hover {
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	-opera-box-shadow: none;
	box-shadow: none;	
}

span.result.significant {
	color: #db4105;
	background-color: #ffdacc;
	border-color: #ffdacc;
}


span.result.active {
	border-color: #0773ba;
	color: #ffffff;
	background-color: #0773ba;
}

.evidence {
	border-top: 5px solid;
	border-color: #60a8c8;
	
	display: block;
	position: absolute;
	left: 0px;
	right:  0px;
	bottom: 0px;	
	background-color: #e0eff6;
	padding-left: 20px;
	padding-right: 20px;
	padding-top: 0px;
	padding-bottom: 10px;

	margin: 0px;	
	
	-webkit-box-shadow: 0px 0px 5px #000000;
	-moz-box-shadow: 0px 0px 5px #000000;
	-opera-box-shadow: 0px 0px 5px #000000;
	box-shadow: 0px 0px 5px #000000;
	overflow: auto;
	z-index: 10;
}

.evidence p {
	margin-top: 0px;
}

.evidence .sectionheader {
	color: #4d87a0;
	margin-left: 0px;
}

.evidence .section .sectionheader {
	padding-bottom: 5px;
	font: bold x-large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .subsection .sectionheader {
	padding-bottom: 5px;
	font: bold large "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .subsubsection .sectionheader {
	padding-bottom: 5px;
	font: bold medium "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.evidence .sectionbody {
	margin: 0;	
}


/* @end */

/* @group resulttable */

.resulttable {
	font-size: small;
	border-style: none;
	border-width: 0px;
	border-collapse: collapse;
	margin-right: auto;
	margin-left: auto;
	font-size: small;
}

.resulttable td {
	font-size: small;
	padding-right: 1ex;
	padding-left: 1ex;
	padding-top: 0.75ex;
	padding-bottom: 0.75ex;
}


.resulttable tr {
}

.resulttable thead {
	font-weight: bold;	
	border-bottom: 1px solid #919191;
	border-collapse: separate;
	vertical-align: top;	
}

.resulttable thead th {
	padding-left: 5px;
	padding-right: 5px;		
}

.resulttable.sortabletable thead th {
	cursor: pointer;
}

.resulttable.sortabletable thead th.headerSortUp { 
	color: #426566;
} 

.resulttable.sortabletable thead th.headerSortDown { 
	color: #426566;
} 


.resulttable tbody {
}

.resulttable tbody tr:nth-child(even) {
	background-color: #e4e4e4;
}

.resulttable thead tr {
}



/* @end */

/* @group table and figure */

.table {
	margin-top: 15px;
	margin-bottom: 15px;
	border: 2px solid #e4e4e4;
	padding: 10px;
}

.evidence .table {
	border-color:  #60a8c8;
}


.figure {
	margin-top: 15px;
	margin-bottom: 15px;
	border: 2px solid #e4e4e4;
	padding: 10px;
}

.evidence .figure {
	border-color:  #60a8c8;
}

.figure .image img {
	display: block;
	cursor: pointer;
	margin-right: auto;
	margin-left: auto;
}

/* for SVG */
.figure .image object {
	display: block;
	cursor: pointer;
	margin-right: auto;
	margin-left: auto;
}



.caption {
	margin-top: 0px;
	margin-bottom: 10px;
	font: small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
}

.caption a.download {
	color: #797979;
	background-color: #ffffff;
	text-decoration: none;
	text-transform: uppercase;
	font: x-small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	padding: 2px 4px 2px 4px;
	border-radius: 0.5em;
	float: right;
	position: relative;
	top: -20px;
	
	padding-left: 5px;
	padding-right: 5px;
	padding-top: 2px;
	padding-bottom: 2px;
	margin-right: 10px;
	border: 1px solid #ccc;
	cursor: pointer;
	border-radius: 0.55ex;
	font: bold x-small "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	text-transform: uppercase;	
	
}

.evidence .caption a.download {
	color: #4d87a0;
	background-color: #e0eff6;
	border: 1px solid #4d87a0;
}


.caption a.download:hover  {
	-webkit-box-shadow: 0px 0px 5px black;
	-moz-box-shadow: 0px 0px 5px black;
	-opera-box-shadow: 0px 0px 5px black;
	box-shadow: 0px 0px 5px black;	
}

.caption a.download:active  {
	-webkit-box-shadow: 0px 0px 20px #000000;
	-moz-box-shadow: 0px 0px 20px #000000;
	-opera-box-shadow: 0px 0px 20px #000000;
	box-shadow: 0px 0px 20px #000000;	
}


/* @end */

